# AGENTS.md 追記例（計画ゲート）

この運用をプロジェクト全体に適用したい場合、`AGENTS.md` に以下を追記する。

```markdown
## Task Design Gate (Mandatory)

- すべてのタスク依頼で、作業開始前に必ずタスク設計書を作成する（例外なし）。
- タスク設計書は `docs/task-designs/` に保存する。未作成ならディレクトリを作成する。
- 実装ファイルの編集は、設計書に対するユーザーの明示承認を得てから開始する。
- 設計書のオープン事項が未解消の間は実装を開始しない。
- 実装中にスコープ変更が生じた場合は一旦停止し、設計書を更新して再承認を得る。
```
